@@ -1,6 +1,6 @@
 package Bundle::WWW::Search::ALL;
 
-$VERSION = '1.04';
+$VERSION = '1.05';
 
 1;
 
@@ -20,25 +20,35 @@ Bundle::WWW::Search
 
 WWW::Search::AllTheWeb
 
+J/JS/JSMYSER/WWW-Search-AltaVista-AdvancedWeb-2.02.tar.gz
+
 WWW::Search::Deja
 
-J/JS/JSMYSER/WWW-Search-EuroSeek-1.2+.tar.gz
+J/JS/JSMYSER/WWW-Search-EuroSeek-1.03.tar.gz
 
 WWW::Search::Excite
 
-J/JS/JSMYSER/WWW-Search-GoTo-1.6+.tar.gz
+J/JS/JSMYSER/WWW-Search-GoTo-1.07.tar.gz
 
 J/JS/JSMYSER/WWW-Search-Google-2.18+.tar.gz
 
 WWW::Search::HotBot
 
-M/MT/MTHURN/WWW-Search-Magellan-2.05.tar.gz
+J/JS/JSMYSER/WWW-Search-LookSmart-2.04.tar.gz
 
-J/JS/JSMYSER/WWW-Search-OpenDirectory.tar.gz
+M/MT/MTHURN/WWW-Search-Magellan-2.06.tar.gz
+
+J/JS/JSMYSER/WWW-Search-MetaCrawler-2.07.tar.gz
+
+J/JS/JSMYSER/WWW-Search-OpenDirectory-2.02.tar.gz
 
 WWW::Search::PRWire
 
-J/JS/JSMYSER/WWW-Search-Snap-2.05+.tar.gz
+J/JS/JSMYSER/WWW-Search-Snap-2.06.tar.gz
+
+WWW::Search::Translator
+
+J/JS/JSMYSER/WWW-Search-X-Search-1.03.tar.gz
 
 M/MT/MTHURN/WWW-Search-Yahoo-2.11.tar.gz
 
